==> estateplat-common-1.2.3-20190301.025841-228-sources.jar: cn/gtmap/estateplat/model/etl/Qlrxx.java <==
package cn.gtmap.estateplat.model.etl;

import java.io.Serializable;

/**
 * @author <a href="mailto:sunchao@gtmap.cn">sunchao</a>
 * @version 1.0, 2018/8/29
 * @description 外网申报登记权利人模型
 */
public class Qlrxx implements Serializable {
    private String qlrid;//权利人ID
    private String sqid;//申请ID
    private String qlrmc;//权利人名称
    private String qlrsfzjzl;//权利人身份证件种类
    private String qlrzjh;//权利人证件号
    private String qlrtxdz;//权利人通讯地址
    private String qlrlx;//权利人类型
    private String qlbl;//权利比例
    private String qlrlxdh;//权利人联系电话
    private String dlrmc;//代理人名称
    private String dlrdh;//代理人电话
    private String fddbrhfzr;//法定代表人或负责人
    private String fddbrhfzrdh;//法定代表人或负责人电话
    private String xb;//性别
    private Integer xh;//序号

    public String getQlrid() {
        return qlrid;
    }

    public void setQlrid(String qlrid) {
        this.qlrid = qlrid;
    }

    public String getSqid() {
        return sqid;
    }

    public void setSqid(String sqid) {
        this.sqid = sqid;
    }

    public String getQlrmc() {
        return qlrmc;
    }

    public void setQlrmc(String qlrmc) {
        this.qlrmc = qlrmc;
    }

    public String getQlrsfzjzl() {
        return qlrsfzjzl;
    }

    public void setQlrsfzjzl(String qlrsfzjzl) {
        this.qlrsfzjzl = qlrsfzjzl;
    }

    public String getQlrzjh() {
        return qlrzjh;
    }

    public void setQlrzjh(String qlrzjh) {
        this.qlrzjh = qlrzjh;
    }

    public String getQlrtxdz() {
        return qlrtxdz;
    }

    public void setQlrtxdz(String qlrtxdz) {
        this.qlrtxdz = qlrtxdz;
    }

    public String getQlrlx() {
        return qlrlx;
    }

    public void setQlrlx(String qlrlx) {
        this.qlrlx = qlrlx;
    }

    public String getQlbl() {
        return qlbl;
    }

    public void setQlbl(String qlbl) {
        this.qlbl = qlbl;
    }

    public String getQlrlxdh() {
        return qlrlxdh;
    }

    public void setQlrlxdh(String qlrlxdh) {
        this.qlrlxdh = qlrlxdh;
    }

    public String getDlrmc() {
        return dlrmc;
    }

    public void setDlrmc(String dlrmc) {
        this.dlrmc = dlrmc;
    }

    public String getDlrdh() {
        return dlrdh;
    }

    public void setDlrdh(String dlrdh) {
        this.dlrdh = dlrdh;
    }

    public String getFddbrhfzr() {
        return fddbrhfzr;
    }

    public void setFddbrhfzr(String fddbrhfzr) {
        this.fddbrhfzr = fddbrhfzr;
    }

    public String getFddbrhfzrdh() {
        return fddbrhfzrdh;
    }

    public void setFddbrhfzrdh(String fddbrhfzrdh) {
        this.fddbrhfzrdh = fddbrhfzrdh;
    }

    public String getXb() {
        return xb;
    }

    public void setXb(String xb) {
        this.xb = xb;
    }

    public Integer getXh() {
        return xh;
    }

    public void setXh(Integer xh) {
        this.xh = xh;
    }
}

==> estateplat-common-1.2.4-20200326.083120-297-sources.jar: cn/gtmap/estateplat/model/etl/Qlrxx.java <==
package cn.gtmap.estateplat.model.etl;

import java.io.Serializable;

/**
 * @author <a href="mailto:sunchao@gtmap.cn">sunchao</a>
 * @version 1.0, 2018/8/29
 * @description 外网申报登记权利人模型
 */
public class Qlrxx implements Serializable {
    private String qlrid;//权利人ID
    private String sqid;//申请ID
    private String qlrmc;//权利人名称
    private String qlrsfzjzl;//权利人身份证件种类
    private String qlrzjh;//权利人证件号
    private String qlrtxdz;//权利人通讯地址
    private String qlrlb;//权利人类型
    private String qlbl;//权利比例
    private String qlrlxdh;//权利人联系电话
    private String dlrmc;//代理人名称
    private String dlrdh;//代理人电话
    private String fddbrhfzr;//法定代表人或负责人
    private String fddbrhfzrdh;//法定代表人或负责人电话
    private String xb;//性别
    private Integer xh;//序号

    public String getQlrid() {
        return qlrid;
    }

    public void setQlrid(String qlrid) {
        this.qlrid = qlrid;
    }

    public String getSqid() {
        return sqid;
    }

    public void setSqid(String sqid) {
        this.sqid = sqid;
    }

    public String getQlrmc() {
        return qlrmc;
    }

    public void setQlrmc(String qlrmc) {
        this.qlrmc = qlrmc;
    }

    public String getQlrsfzjzl() {
        return qlrsfzjzl;
    }

    public void setQlrsfzjzl(String qlrsfzjzl) {
        this.qlrsfzjzl = qlrsfzjzl;
    }

    public String getQlrzjh() {
        return qlrzjh;
    }

    public void setQlrzjh(String qlrzjh) {
        this.qlrzjh = qlrzjh;
    }

    public String getQlrtxdz() {
        return qlrtxdz;
    }

    public void setQlrtxdz(String qlrtxdz) {
        this.qlrtxdz = qlrtxdz;
    }

    public String getQlrlb() {
        return qlrlb;
    }

    public void setQlrlb(String qlrlx) {
        this.qlrlb = qlrlx;
    }

    public String getQlbl() {
        return qlbl;
    }

    public void setQlbl(String qlbl) {
        this.qlbl = qlbl;
    }

    public String getQlrlxdh() {
        return qlrlxdh;
    }

    public void setQlrlxdh(String qlrlxdh) {
        this.qlrlxdh = qlrlxdh;
    }

    public String getDlrmc() {
        return dlrmc;
    }

    public void setDlrmc(String dlrmc) {
        this.dlrmc = dlrmc;
    }

    public String getDlrdh() {
        return dlrdh;
    }

    public void setDlrdh(String dlrdh) {
        this.dlrdh = dlrdh;
    }

    public String getFddbrhfzr() {
        return fddbrhfzr;
    }

    public void setFddbrhfzr(String fddbrhfzr) {
        this.fddbrhfzr = fddbrhfzr;
    }

    public String getFddbrhfzrdh() {
        return fddbrhfzrdh;
    }

    public void setFddbrhfzrdh(String fddbrhfzrdh) {
        this.fddbrhfzrdh = fddbrhfzrdh;
    }

    public String getXb() {
        return xb;
    }

    public void setXb(String xb) {
        this.xb = xb;
    }

    public Integer getXh() {
        return xh;
    }

    public void setXh(Integer xh) {
        this.xh = xh;
    }
}
